pub struct WeightedTable<T>{ /* private fields */ }Expand description
WeightedTable
This is a simple implementation of a weighted table. It is designed to be used with a random number generator. It can be used as follows:
use rantz_random::prelude::{WeightedTable, RandomContainer};
let mut table = WeightedTable::new();
table.insert("Bob", 10); // Bob has a weight of 10
table.insert("Alice", 20); // Alice has a weight of 20
table.remove(&"Bob"); // Bob is removed
table.random(); // Returns a random element from the table based on the weightsThe table is iterable and returns owned tuples of (value, weight)
For references, use the iter method
For mutable references, use the [iter_mut](WeightedTable::iter_mut) method
use rantz_random::prelude::WeightedTable;
let mut table = WeightedTable::new();
table.insert("Bob".to_string(), 10); // Bob has a weight of 10
table.insert("Alice".to_string(), 20); // Alice has a weight of 20
for (value, weight) in table.iter() {
println!("Reference {} has a weight of {}", value, weight);
}
for (value, weight) in table.iter_mut() {
*value += " Test";
*weight += 10;
println!("Reference {} has a weight of {}", value, weight);
}
for value in table { // Must be done last as consumes the table
println!("Owned {}", value);
}Adding an element that already exists will update the weight of the existing element.
Implementations
Sourceimpl<T> WeightedTable<T>
impl<T> WeightedTable<T>
Sourcepub fn new() -> WeightedTable<T>
pub fn new() -> WeightedTable<T>
Creates a new empty WeightedTable
Sourcepub fn from_vec(vec: Vec<(T, u32)>) -> WeightedTable<T>
pub fn from_vec(vec: Vec<(T, u32)>) -> WeightedTable<T>
Creates a new WeightedTable from a vector of tuples
of (value, weight)
Sourcepub fn get_entry(&self, index: usize) -> Option<(T, u32)>
pub fn get_entry(&self, index: usize) -> Option<(T, u32)>
Returns the entry at the specified index
Sourcepub fn get_entry_ref(&self, index: usize) -> Option<(&T, &u32)>
pub fn get_entry_ref(&self, index: usize) -> Option<(&T, &u32)>
Returns the entry at the specified index as a reference
Sourcepub fn get_entry_mut(&mut self, index: usize) -> Option<(&mut T, &mut u32)>
pub fn get_entry_mut(&mut self, index: usize) -> Option<(&mut T, &mut u32)>
Returns the entry at the specified index as a mutable reference
Sourcepub fn get_weight(&self, value: &T) -> Option<u32>
pub fn get_weight(&self, value: &T) -> Option<u32>
Returns the weight of the specified value
Sourcepub fn get_weight_mut(&mut self, value: &T) -> Option<&mut u32>
pub fn get_weight_mut(&mut self, value: &T) -> Option<&mut u32>
Returns the weight of the specified value as a mutable reference
Sourcepub fn random_with(&self, n: u32) -> (T, u32)
pub fn random_with(&self, n: u32) -> (T, u32)
Returns a random element with the specified weight
Sourcepub fn iter_mut(&mut self) -> impl Iterator<Item = (&mut T, &mut u32)>
pub fn iter_mut(&mut self) -> impl Iterator<Item = (&mut T, &mut u32)>
Returns an iterator over the table mutably
Sourcepub fn combine(&mut self, other: WeightedTable<T>)
pub fn combine(&mut self, other: WeightedTable<T>)
Combines two tables (in place)